darkhistory.physics.mass — DarkHistory documentation

# darkhistory.physics.mass

`darkhistory.physics.` `mass` = {'W': 80379000000.0, 'Z': 91187600000.0, 'b': 4180000000.0, 'c': 1275000000.0, 'e': 510998.9461, 'h': 125180000000.0, 'mu': 105658374.5, 't': 173100000000.0, 'tau': 1776860000.0}

  Masses of Standard Model particles.

#### Previous topic

darkhistory.physics.ele

#### Next topic

darkhistory.physics.thomson_xsec

### This Page

Show Source